use crate::config::Config;
use serde_json::{json, Value};

pub fn get_zabbix_authtoken(cfg: &mut Config) {
    let body = query_auth_token(&cfg.username, &cfg.password);
    let response = reqwest::blocking::Client::new()
        .post(&cfg.server)
        .json(&body)
        .send()
        .unwrap();

    let values: Value = response.json().unwrap();
    cfg.authtoken = Some(values["result"].as_str().unwrap().to_string());
}

pub fn get_zabbix_problems(cfg: &mut Config) {
    let body = query_problems(&cfg.authtoken.as_ref().unwrap_or(&String::from("")),
                                    cfg.limit.unwrap());
    let response = reqwest::blocking::Client::new()
        .post(&cfg.server)
        .json(&body)
        .send()
        .unwrap();

    let _values: Value = response.json().unwrap();
    // for i in values["result"].as_array().unwrap() {
    //     println!("{}", i);
    // }
}

pub fn query_auth_token(username: &String,
                        password: &String) -> Value {
    json!({
        "jsonrpc": "2.0",
        "method": "user.login",
        "params": {
            "user": username,
            "password": password
        },
        "id": 1
    })
}

pub fn query_problems(token: &String,
                      limit: i64) -> Value {
    json!({
        "jsonrpc": "2.0",
        "method": "problem.get",
        "params": {
            "output": "extend",
            "selectAcknowledges": "extend",
            "selectTags": "extend",
            "selectSuppressionData": "extend",
            "recent": "true",
            "sortfield": ["eventid"],
            "sortorder": "DESC",
            "limit": limit
        },
        "auth": token,
        "id": 1
    })
}